@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2005 by the monit project group.
+ * Copyright (C), 2000-2006 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -33,9 +33,10 @@
 /** Default mail message */
 #define ALERT_MESSAGE "$EVENT Service $SERVICE \r\n"\
                       "\r\n"\
-                      "\tDate:   $DATE\r\n"\
-                      "\tAction: $ACTION\r\n"\
-	              "\tHost:   $HOST\r\n"\
+                      "\tDate:        $DATE\r\n"\
+                      "\tAction:      $ACTION\r\n"\
+	              "\tHost:        $HOST\r\n"\
+	              "\tDescription: $DESCRIPTION\r\n"\
 		      "\r\n"\
 		      "Your faithful employee,\r\n"\
 	              "monit\r\n"
@@ -52,7 +53,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: alert.h,v 1.18 2005/01/06 20:51:49 martinp Exp $
+ *  @version \$Id: alert.h,v 1.22 2006/01/01 22:44:01 martinp Exp $
  *  @file
  */
 
@@ -60,8 +61,9 @@
 /**
  * Notify registred users about the event
  * @param E An Event object
+ * @return If failed, return HANDLER_ALERT flag or HANDLER_PASSED flag if passed
  */
-void handle_alert(Event_T E);
+int handle_alert(Event_T E);
 
 
 #endif
