@@ -60,7 +60,7 @@
  *  @author Rory Toma, <rory@digeo.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: control.c,v 1.103 2006/04/27 20:16:03 martinp Exp $
+ *  @version \$Id: control.c,v 1.104 2006/06/28 09:02:43 martinp Exp $
  *
  *  @file
  */
@@ -128,23 +128,40 @@ error:
 /**
  * Check to see if we should try to start/stop service
  * @param S A service name as stated in the config file
- * @param action A string describing the action to execute
- * @return TRUE if the service was handled successfully otherwise FALSE
+ * @param A A string describing the action to execute
  */
-void control_service(const char *S, const char *action) {
+void control_service_string(const char *S, const char *A) {
+
+  int a;
+
+  ASSERT(S);
+  ASSERT(A);
+
+  if((a = Util_getAction(A)) == ACTION_IGNORE) {
+    LogError("%s: service '%s' -- invalid action %s\n", prog, S, A);
+    return;
+  }
+  control_service(S, a);
+}
+
+
+/**
+ * Check to see if we should try to start/stop service
+ * @param S A service name as stated in the config file
+ * @param A An action id describing the action to execute
+ */
+void control_service(const char *S, int A) {
 
   Service_T s = NULL;
 
   ASSERT(S);
-  ASSERT(action);
 
   if(!(s= Util_getService(S))) {
-    LogError("%s: Cannot %s service '%s' -- not found in %s\n",
-        prog, action, S, Run.controlfile);
+    LogError("%s: service '%s' -- doesn't exist\n", prog, S);
     return;
   }
 
-  switch(Util_getAction(action)) {
+  switch(A) {
 
     case ACTION_START:
       if(s->type==TYPE_PROCESS) {
@@ -212,8 +229,7 @@ void control_service(const char *S, const char *action) {
       break;
 
     default:
-      LogError("%s: Cannot %s service '%s' -- invalid action %s\n",
-          prog, action, S, action);
+      LogError("%s: service '%s' -- invalid action %s\n", prog, S, A);
       break;
   }
 }
