@@ -23,7 +23,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_LINUX.c,v 1.13 2006/04/27 20:16:03 martinp Exp $
+ *  @version \$Id: sysdep_LINUX.c,v 1.15 2006/07/19 19:17:28 martinp Exp $
  *
  *  @file
  */
@@ -46,8 +46,8 @@
 #include <strings.h>
 #endif
 
-#ifdef HAVE_SYS_VFS_H
-# include <sys/vfs.h>
+#ifdef HAVE_SYS_STATVFS_H
+# include <sys/statvfs.h>
 #endif
 
 #ifdef HAVE_MNTENT_H
@@ -109,22 +109,23 @@ char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
  */
 int device_usage_sysdep(Info_T inf) {
 
-  struct statfs usage;
+  struct statvfs usage;
 
   ASSERT(inf);
 
-  if(statfs(inf->mntpath, &usage) != 0) {
+  if(statvfs(inf->mntpath, &usage) != 0) {
     LogError("%s: Error getting usage statistics for device '%s' -- %s\n",
         prog, inf->mntpath, STRERROR);
     return FALSE;
   }
 
   inf->f_bsize=           usage.f_bsize;
-  inf->f_blocks=          usage.f_blocks;
+  inf->f_blocks=          usage.f_blocks * usage.f_frsize / usage.f_bsize;
   inf->f_blocksfree=      usage.f_bavail;
   inf->f_blocksfreetotal= usage.f_bfree;
   inf->f_files=           usage.f_files;
   inf->f_filesfree=       usage.f_ffree;
+  inf->flags=             usage.f_flag;
 
   return TRUE;
 
