@@ -22,7 +22,7 @@
  *
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_NETBSD.c,v 1.4 2006/04/27 20:16:03 martinp Exp $
+ *  @version \$Id: sysdep_NETBSD.c,v 1.6 2006/10/31 22:27:55 martinp Exp $
  *
  *  @file
  */
@@ -49,6 +49,10 @@
 #include <sys/mount.h>
 #endif
 
+#ifdef HAVE_SYS_STATVFS_H
+#include <sys/statvfs.h>
+#endif
+
 #include "monitor.h"
 #include "device_sysdep.h"
 
@@ -63,12 +67,20 @@
  */
 char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
 
+#if(__NetBSD_Version__ >= 300000000)
+  struct statvfs usage;
+#else
   struct statfs usage;
+#endif
 
   ASSERT(inf);
   ASSERT(blockdev);
 
+#if(__NetBSD_Version__ >= 300000000)
+  if(statvfs(blockdev, &usage) != 0) {
+#else
   if(statfs(blockdev, &usage) != 0) {
+#endif
     LogError("%s: Error getting mountpoint for device '%s' -- %s\n",
         prog, blockdev, STRERROR);
     return NULL;
@@ -88,11 +100,19 @@ char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
  */
 int device_usage_sysdep(Info_T inf) {
 
+#if(__NetBSD_Version__ >= 300000000)
+  struct statvfs usage;
+#else
   struct statfs usage;
+#endif
 
   ASSERT(inf);
 
+#if(__NetBSD_Version__ >= 300000000)
+  if(statvfs(inf->mntpath, &usage) != 0) {
+#else
   if(statfs(inf->mntpath, &usage) != 0) {
+#endif
     LogError("%s: Error getting usage statistics for device '%s' -- %s\n",
         prog, inf->mntpath, STRERROR);
     return FALSE;
@@ -104,6 +124,11 @@ int device_usage_sysdep(Info_T inf) {
   inf->f_blocksfreetotal= usage.f_bfree;
   inf->f_files=           usage.f_files;
   inf->f_filesfree=       usage.f_ffree;
+#if(__NetBSD_Version__ >= 300000000)
+  inf->flags=             usage.f_flag;
+#else
+  inf->flags=             usage.f_flags;
+#endif
 
   return TRUE;
 
