@@ -23,7 +23,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_UNKNOWN.c,v 1.10 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: sysdep_UNKNOWN.c,v 1.11 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -42,7 +42,7 @@
  */
 char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
 
-  log("%s: Unsupported mounted filesystem information method", prog);
+  LogError("%s: Unsupported mounted filesystem information method", prog);
 
   return NULL;
 
@@ -57,7 +57,8 @@ char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
  */
 int device_usage_sysdep(Info_T inf) {
 
-  log("%s: Unsupported filesystem informations gathering method\n", prog);
+  LogError("%s: Unsupported filesystem informations gathering method\n",
+    prog);
 
   return FALSE;
 
