@@ -54,7 +54,7 @@
  *
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  * @author Martin Pala <martinp@tildeslash.com>
- * @version \$Id: event.c,v 1.61 2006/04/27 20:16:03 martinp Exp $
+ * @version \$Id: event.c,v 1.62 2006/06/28 09:02:43 martinp Exp $
  * @file
  */
 
@@ -88,7 +88,7 @@ EventTable_T Event_Table[]= {
 
 
 static void handle_event(Event_T);
-static int  handle_action(Event_T, Action_T);
+static void handle_action(Event_T, Action_T);
 static void Event_queue_add(Event_T);
 
 
@@ -748,7 +748,7 @@ static void handle_event(Event_T E) {
 }
 
 
-static int handle_action(Event_T E, Action_T A) {
+static void handle_action(Event_T E, Action_T A) {
 
   Service_T s;
 
@@ -759,7 +759,7 @@ static int handle_action(Event_T E, Action_T A) {
 
   if(A->id == ACTION_IGNORE)
   {
-    return TRUE;
+    return;
   }
 
   /* Alert and collector event notification are common actions */
@@ -780,60 +780,40 @@ static int handle_action(Event_T E, Action_T A) {
     }
   }
 
-  s = Event_get_source(E);
-  if(!s)
+  if(!(s = Event_get_source(E)))
   {
     LogError("Event action handling aborted\n");
-    return FALSE;
+    return;
   }
 
-  switch(A->id)
+  if(A->id == ACTION_ALERT)
   {
-  case ACTION_ALERT:
-      /* Already handled. */
-      break;
-
-  case ACTION_EXEC:
-      spawn(s, A->exec, Event_get_description(E));
-      break;
-
-  case ACTION_RESTART:
-      if(s->def_timeout)
-        s->nstart++;
-      if((s->mode != MODE_PASSIVE))
-      {
-        control_service(s->name, "restart");
-      }
-      return FALSE;
-
-  case ACTION_START:
-      if(s->def_timeout)
-        s->nstart++;
-      if((s->mode != MODE_PASSIVE))
-      {
-        control_service(s->name, "start");
-      } 
-      return FALSE;
-
-  case ACTION_STOP:
-      if((s->mode != MODE_PASSIVE))
-      {
-        control_service(s->name, "stop");
-      } 
-      return FALSE;
-
-  case ACTION_UNMONITOR:
-      control_service(s->name, "unmonitor");
-      return FALSE;
-
-  default:
-      LogError("'%s' error -- unknown failure action: [%d]\n", s->name,
-        A->id);
-      break;
-
+    return;     /* Already handled */
   }
+  else if(A->id == ACTION_EXEC)
+  {
+    spawn(s, A->exec, Event_get_description(E));
+    return;
+  }
+  else 
+  {
+    if(s->def_timeout &&
+         (A->id == ACTION_START ||
+          A->id == ACTION_RESTART))
+    {
+      s->nstart++;
+    }
 
-  return TRUE;
+    if(s->mode == MODE_PASSIVE &&
+         (A->id == ACTION_START ||
+          A->id == ACTION_STOP  ||
+          A->id == ACTION_RESTART))
+    {
+      return;
+    }
+
+    control_service(s->name, A->id);
+  }
 }
 
 
