@@ -68,7 +68,7 @@ static void _gc_request(Request_T *);
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: gc.c,v 1.66 2006/01/01 22:44:01 martinp Exp $
+ *  @version \$Id: gc.c,v 1.67 2006/07/19 17:33:37 martinp Exp $
  *
  *  @file
  */
@@ -223,6 +223,9 @@ static void _gc_service(Service_T *s) {
   if((*s)->action_PPID)
     _gc_eventaction(&(*s)->action_PPID);
   
+  if((*s)->action_FSFLAG)
+    _gc_eventaction(&(*s)->action_FSFLAG);
+  
   if((*s)->action_MONIT_START)
     _gc_eventaction(&(*s)->action_MONIT_START);
   
