@@ -146,7 +146,7 @@ static char *get_service_status_text(Service_T);
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: cervlet.c,v 1.202 2006/01/08 21:36:42 martinp Exp $
+ *  @version \$Id: cervlet.c,v 1.210 2006/07/19 19:10:34 martinp Exp $
  *
  *  @file
  */
@@ -161,7 +161,7 @@ static char *get_service_status_text(Service_T);
  */
 void init_service() {
   
-  add_Impl((void *) doGet, (void *) doPost);
+  add_Impl(doGet, doPost);
   
 }
 
@@ -593,104 +593,35 @@ static void handle_action(HttpRequest req, HttpResponse res) {
   
   if(Util_existService(++name)) {
 
-    Service_T s= Util_getService(name);
+    Service_T s;
 
-    if(s == NULL) {
+    if(!(s = Util_getService(name))) {
       send_error(res, SC_BAD_REQUEST, "There is no service by that name");
       return;
     }
-
     if(!action) {
-
       do_service(req, res, s);
-
     } else {
-      
       if(is_readonly(req)) {
-	send_error(res, SC_FORBIDDEN,
-		   "You do not have sufficent privilegs to access this page");
-	return;
+        send_error(res, SC_FORBIDDEN,
+          "You do not have sufficent privilegs to access this page");
+        return;
       }
-
-      if(IS(action, "start")) {
-	if(s->start) {
-	  LOCK(s->mutex)
-	      control_service(name, action);
-	      if(s->type==TYPE_PROCESS) {
-		/* Wait for the service to start (or fail) */
-		int max_tries= Run.polltime;
-		while(max_tries-- && !Run.stopped) {
-		  if(Util_isProcessRunning(s))
-		      break;
-		  sleep(1);
-		}
-	      }
-	  END_LOCK;
-	  if(s->type==TYPE_PROCESS && !Util_isProcessRunning(s)) {
-	    send_error(res, SC_INTERNAL_SERVER_ERROR,
-		       "Could not start the service");
-	    goto quit;
-	  }
-	} else {
-          send_error(res, SC_BAD_REQUEST,
-	             "Start method not defined for the service");
-	  goto quit;
-	}
-      } else if(IS(action, "stop")) {
-	if(s->stop) {
-	  LOCK(s->mutex)
-	      control_service(name, action);
-	  END_LOCK;
-	} else {
-          send_error(res, SC_BAD_REQUEST,
-	             "Stop method not defined for the service");
-	  goto quit;
-	}
-      } else if(IS(action, "restart")) {
-	if(s->start && s->stop) {
- 	  LOCK(s->mutex)
-	      control_service(name, action);
-	      if(s->type==TYPE_PROCESS) {
-		/* Wait for the service to restart (or fail) */
-		int max_tries= Run.polltime;
-		while(max_tries-- && !Run.stopped) {
-		  if(Util_isProcessRunning(s))
-		      break;
-		  sleep(1);
-		}
-	      }
-	  END_LOCK;
-	  if(s->type==TYPE_PROCESS && !Util_isProcessRunning(s)) {
-	    send_error(res, SC_INTERNAL_SERVER_ERROR,
-		       "Could not restart the service");
-	    goto quit;
-	  }
-	} else {
-          send_error(res, SC_BAD_REQUEST,
-		     "Start or stop method not defined for the service");
-	  goto quit;
-	}
-      } else if(IS(action, "monitor")) {
-	  LOCK(s->mutex)
-	    control_service(name, action);
-	  END_LOCK;
-      } else if(IS(action, "unmonitor")) {
-	  LOCK(s->mutex)
-	    control_service(name, action);
-	  END_LOCK;
+      if((s->doaction = Util_getAction(action)) == ACTION_IGNORE) {
+        send_error(res, SC_BAD_REQUEST, "Invalid action");
+        return;
       }
-
+      /* Set the global flag if action is pending */
+      if(s->doaction) {
+        Run.doaction = TRUE;
+      }
+      do_wakeupcall();
       send_redirect(res, req->url);
-
     }
-
   } else {
-
     not_found(req, res);
-
   }
 
-  quit:
   reset_depend();
 
 }
@@ -1133,11 +1064,11 @@ static void do_home_file(HttpRequest req, HttpResponse res) {
     } else {
       
       out_print(res,
-	"<td align=\"right\">%lu&nbsp;B</td>"
+	"<td align=\"right\">%llu&nbsp;B</td>"
 	"<td align=\"right\">%o</td>"
 	"<td align=\"right\">%d</td>"
 	"<td align=\"right\">%d</td>",
-	(unsigned long)s->inf->st_size,
+	(unsigned long long)s->inf->st_size,
 	s->inf->st_mode & 07777,
 	s->inf->st_uid,
 	s->inf->st_gid);
@@ -1663,6 +1594,15 @@ static void print_service_rules_timestamp(HttpResponse res, Service_T s) {
 
 static void print_service_rules_device(HttpResponse res, Service_T s) {
 
+  if(s->type == TYPE_DEVICE) {
+
+    char ratio1[STRLEN];
+
+    out_print(res, "<tr><td>Filesystem flags</td><td>If changed %s then %s</td></tr>\n",
+      Util_getEventratio(s->action_FSFLAG->failed, ratio1),
+      actionnames[s->action_FSFLAG->failed->id]);
+  }
+
   if(s->devicelist) {
       
     char          ratio1[STRLEN];
@@ -1748,7 +1688,7 @@ static void print_service_rules_size(HttpResponse res, Service_T s) {
 
         out_print(res,
           "<tr><td>Associated size</td>"
-          "<td>If %s %lu byte(s) %s then %s else if passed %s then %s</td></tr>",
+          "<td>If %s %llu byte(s) %s then %s else if passed %s then %s</td></tr>",
           operatornames[sl->operator], sl->size,
           ratio1, actionnames[a->failed->id],
           ratio2, actionnames[a->passed->id]);
@@ -2172,6 +2112,8 @@ static void print_service_params_device(HttpResponse res, Service_T s) {
 
     if(!Util_hasServiceStatus(s)) {
 
+      out_print(res,
+        "<tr><td>Filesystem flags</td><td>-</td></tr>");
       out_print(res,
         "<tr><td>Blocks total</td><td>-</td></tr>");
       out_print(res,
@@ -2187,6 +2129,9 @@ static void print_service_params_device(HttpResponse res, Service_T s) {
 
     } else {
 
+      out_print(res,
+        "<tr><td>Filesystem flags</td><td>%#lx</td></tr>",
+        s->inf->flags);
       out_print(res,
         "<tr><td>Blocks total</td><td>%ld [%.1f MB]</td></tr>",
         s->inf->f_blocks,
@@ -2235,9 +2180,9 @@ static void print_service_params_size(HttpResponse res, Service_T s) {
     } else {
 
       out_print(res,
-        "<tr><td>Size</td><td><font%s>%lu B</td></tr>",
+        "<tr><td>Size</td><td><font%s>%llu B</td></tr>",
         (s->error & EVENT_SIZE)?" color='#ff0000'":"",
-        (unsigned long) s->inf->st_size);
+        (unsigned long long) s->inf->st_size);
 
     }
   }
@@ -2484,8 +2429,8 @@ static void status_service_txt(Service_T s, HttpResponse res, short level) {
       }
       if(s->type == TYPE_FILE) {
         out_print(res,
-  		"  %-33s %lu B\n",
-  		"size", (unsigned long) s->inf->st_size);
+  		"  %-33s %llu B\n",
+  		"size", (unsigned long long) s->inf->st_size);
         if(s->checksum) {
   	out_print(res,
   		  "  %-33s %s(%s)\n",
@@ -2495,10 +2440,13 @@ static void status_service_txt(Service_T s, HttpResponse res, short level) {
       }
       if(s->type == TYPE_DEVICE) {
         out_print(res,
+  		"  %-33s %#lx\n"
   		"  %-33s %ld B\n"
   		"  %-33s %ld [%.1f MB]\n"
   		"  %-33s %ld [%.1f MB] [%.1f%%]\n"
   		"  %-33s %ld [%.1f MB] [%.1f%%]\n",
+  		"filesystem flags",
+  		s->inf->flags,
   		"block size",
   		s->inf->f_bsize,
   		"blocks total",
@@ -2617,23 +2565,36 @@ static void status_service_txt(Service_T s, HttpResponse res, short level) {
 
 static char *get_service_status_html(Service_T s) {
 
-  char state[STRLEN];
+  char         *status= NULL;
+  char          doaction[STRLEN];
   EventTable_T *et= Event_Table;
 
   ASSERT(s);
 
+  memset(doaction, 0, STRLEN);
+  if(s->doaction) {
+    snprintf(doaction, STRLEN-1, " - %s pending", actionnames[s->doaction]);
+  }
+
+  status= xcalloc(sizeof(char), STRLEN);
+  
   /* In the case that the service is not monitored, we will return immediately,
    * because we are not able to describe actual service state */
-  if(s->monitor == MONITOR_NOT)
-    return xstrdup("<font color='#ff8800'>not monitored</font>");
-  else if(s->monitor == MONITOR_INIT)
-    return xstrdup("<font color='#ff8800'>initializing</font>");
+  if(s->monitor == MONITOR_NOT) {
+    snprintf(status, STRLEN, "<font color='#ff8800'>not monitored%s</font>",
+      doaction);
+    return status;
+  } else if(s->monitor == MONITOR_INIT) {
+    snprintf(status, STRLEN, "<font color='#ff8800'>initializing%s</font>",
+      doaction);
+    return status;
+  }
 
   /* In the case that error is zero, service is up without errors */
   if(!s->error) {
-    snprintf(state, STRLEN-1, "<font color='#00ff00'>%s</font>",
-             statusnames[s->type]);
-    return xstrdup(state);
+    snprintf(status, STRLEN, "<font color='#00ff00'>%s%s</font>",
+      statusnames[s->type], doaction);
+    return status;
   }
 
   /* In the case that the service has actualy some failure, error
@@ -2641,35 +2602,50 @@ static char *get_service_status_html(Service_T s) {
    * of the first error found */
   while((*et).id) {
     if(s->error & (*et).id) {
-      snprintf(state, STRLEN-1, "<font color='#ff0000'>%s</font>",
-               (*et).description_failed);
-      return xstrdup(state);
+      snprintf(status, STRLEN, "<font color='#ff0000'>%s%s</font>",
+        (*et).description_failed, doaction);
+      return status;
     }
     et++;
   }
 
   /* We should not pass through here */
-  return xstrdup("<font color='#ff0000'>unknown</font>");
+  snprintf(status, STRLEN, "<font color='#ff0000'>unknown%s</font>",
+    doaction);
+  return status;
 
 }
 
 
 static char *get_service_status_text(Service_T s) {
 
+  char         *status= NULL;
+  char          doaction[STRLEN];
   EventTable_T *et= Event_Table;
 
   ASSERT(s);
 
+  memset(doaction, 0, STRLEN);
+  if(s->doaction) {
+    snprintf(doaction, STRLEN, " - %s pending", actionnames[s->doaction]);
+  }
+
+  status= xcalloc(sizeof(char), STRLEN);
+  
   /* In the case that the service is not monitored, we will return immediately,
    * because we are not able to describe actual service state */
-  if(s->monitor == MONITOR_NOT)
-    return xstrdup("not monitored");
-  else if(s->monitor == MONITOR_INIT)
-    return xstrdup("initializing");
+  if(s->monitor == MONITOR_NOT) {
+    snprintf(status, STRLEN, "not monitored%s", doaction);
+    return status;
+  } else if(s->monitor == MONITOR_INIT) {
+    snprintf(status, STRLEN, "initializing%s", doaction);
+    return status;
+  }
 
   /* In the case that error is zero, service is up without errors */
   if(!s->error) {
-    return xstrdup(statusnames[s->type]);
+    snprintf(status, STRLEN, "%s%s", statusnames[s->type], doaction);
+    return status;
   }
 
   /* In the case that the service has actualy some failure, error
@@ -2677,13 +2653,15 @@ static char *get_service_status_text(Service_T s) {
    * of the first error found */
   while((*et).id) {
     if(s->error & (*et).id) {
-      return xstrdup((*et).description_failed);
+      snprintf(status, STRLEN, "%s%s", (*et).description_failed, doaction);
+      return status;
     }
     et++;
   }
 
   /* We should not pass through here */
-  return xstrdup("unknown");
+  snprintf(status, STRLEN, "unknown%s", doaction);
+  return status;
 
 }
 
