@@ -107,7 +107,7 @@
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *  @author Martin Pala <martinp@tildeslash.com>
  *
- *  @version \$Id: engine.c,v 1.72 2006/04/27 20:16:03 martinp Exp $
+ *  @version \$Id: engine.c,v 1.73 2006/06/29 21:08:32 martinp Exp $
  *
  *  @file 
  */
@@ -263,24 +263,24 @@ int add_host_allow(char *name) {
 
           if((p->network == h->network) && ((p->mask == h->mask))) {
             DEBUG("%s: Debug: Skipping redundant host '%s' (%s).\n",
-                  prog, name, inet_ntoa(*(struct in_addr *) &h->network)); 
+                  prog, name, inet_ntoa(*inp)); 
 
             destroy_host_allow(h);
-	    goto done;
+            goto done;
 	  
-	  }
+          }
 	
         }
 
         DEBUG("%s: Debug: Adding host allow '%s' (%s).\n",
-              prog, name, inet_ntoa(*(struct in_addr *) &h->network)); 
+              prog, name, inet_ntoa(*inp)); 
         
         n->next= h;
       
       } else {
       
         DEBUG("%s: Debug: Adding host allow '%s' (%s).\n",
-              prog, name, inet_ntoa(*(struct in_addr *) &h->network));
+              prog, name, inet_ntoa(*inp));
         
         hostlist= h;
       
