@@ -101,7 +101,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: processor.c,v 1.55 2006/04/27 20:16:03 martinp Exp $
+ *  @version \$Id: processor.c,v 1.56 2006/06/23 20:47:39 martinp Exp $
  *
  *  @file
  */
@@ -157,9 +157,9 @@ void *http_processor(Socket_T s) {
  * @param doGetFunc doGet function
  * @param doPostFunc doPost function 
  */
-void add_Impl(void *doGetFunc, void *doPostFunc) {
-  Impl.doGet= doGetFunc;
-  Impl.doPost= doPostFunc;
+void add_Impl(void(*doGet)(HttpRequest, HttpResponse), void(*doPost)(HttpRequest, HttpResponse)) {
+  Impl.doGet= doGet;
+  Impl.doPost= doPost;
 }
 
 
