@@ -106,7 +106,7 @@ void *http_processor(Socket_T);
 char *get_headers(HttpResponse res);
 void set_status(HttpResponse res, int status);
 const char *get_status_string(int status_code);
-void add_Impl(void *doGetFunc, void *doPostFunc);
+void add_Impl(void(*doGet)(HttpRequest, HttpResponse), void(*doPost)(HttpRequest, HttpResponse));
 void out_print(HttpResponse res,  const char *, ...);
 void set_content_type(HttpResponse res, const char *mime);
 const char *get_header(HttpRequest req, const char *header_name);
