@@ -81,7 +81,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: monitor.c,v 1.129 2006/04/27 20:16:03 martinp Exp $
+ *  @version \$Id: monitor.c,v 1.133 2006/10/30 12:16:41 martinp Exp $
  *
  *  @file
  */
@@ -294,6 +294,10 @@ static void do_reinit() {
   if(Run.dohttpd)
     monit_http(STOP_HTTP);
 
+  /* Save the current state (no changes are possible now
+     since the http thread is stopped) */
+  State_save();
+
   /* wait for all wait_start threads to finish */
   while(Run.wait_start)
     sleep(1);
@@ -361,7 +365,7 @@ static void do_action(char **args) {
     if(service) {
 
       void (*_control_service)(const char *, const char *)=
-        exist_daemon()?control_service_daemon:control_service;
+        exist_daemon()?control_service_daemon:control_service_string;
 
       if(IS(service, "all")) {
 
@@ -486,7 +490,10 @@ static void do_default() {
 
       validate();
       State_save();
-      sleep(Run.polltime);
+
+      /* In the case that there is no pending action then sleep */
+      if(!Run.doaction)
+        sleep(Run.polltime);
 
       if(Run.dowakeup) {
         Run.dowakeup = FALSE;
