@@ -493,7 +493,7 @@ typedef struct mytimestamp {
 /** Defines size object */
 typedef struct mysize {
   int  operator;                                    /**< Comparison operator */
-  unsigned long size;                                    /**< Size watermark */
+  unsigned long long size;                               /**< Size watermark */
   int  test_changes;            /**< TRUE if we only should test for changes */
   EventAction_T action;  /**< Description of the action upon event occurence */
   
@@ -583,10 +583,12 @@ typedef struct myinfo {
   long   inode_total;                          /**< Used inode total objects */
   int    space_percent;                      /**< Used space percentage * 10 */
   long   space_total;                           /**< Used space total blocks */
+  int    _flags;                       /**< Filesystem flags from last cycle */
+  int    flags;                      /**< Filesystem flags from actual cycle */
 
   /* File specific */
-  size_t st_size;                                                  /**< Size */
-  size_t readpos;                           /**< Position for regex matching */
+  off_t st_size;                                                   /**< Size */
+  off_t readpos;                            /**< Position for regex matching */
   ino_t  st_ino_prev;                 /**< Previous inode for regex matching */
   char  *cs_sum;                                               /**< Checksum */
 
@@ -646,8 +648,9 @@ typedef struct myservice {
   Timestamp_T timestamplist;                       /**< Timestamp check list */
   Uid_T       uid;                                            /**< Uid check */
   
-  EventAction_T action_PID;   /**< Description of the action upon pid change */
-  EventAction_T action_PPID; /**< Description of the action upon ppid change */
+  EventAction_T action_PID;                      /**< Action upon pid change */
+  EventAction_T action_PPID;                    /**< Action upon ppid change */
+  EventAction_T action_FSFLAG;      /**< Action upon filesystem flags change */
 
   /** General event handlers */
   EventAction_T action_DATA;       /**< Description of the action upon event */
@@ -665,6 +668,7 @@ typedef struct myservice {
   unsigned long long error;                          /**< Error flags bitmap */
   Info_T             inf;                          /**< Service check result */
   time_t             collected;                /**< When were data collected */
+  int                doaction;          /**< Action scheduled by http thread */
 
   /** Events */
   struct myevent {
@@ -731,6 +735,7 @@ struct myrun {
   char *bind_addr;                  /**< The address monit http will bind to */
   int  doreload;             /**< TRUE if a monit daemon should reinitialize */
   int  dowakeup;           /**< TRUE if a monit daemon was wake up by signal */
+  int  doaction;             /**< TRUE if some service(s) has action pending */
   mode_t umask;                /**< The initial umask monit was started with */
   int  testing;   /**< Running in configuration testing mode - TRUE or FALSE */
   int  wait_start;         /**< Number of threads waiting for process' start */
@@ -788,7 +793,8 @@ extern int            oldptreesize;
 /* FIXME: move remaining prototypes into seperate header-files */
 
 int   parse(char *);
-void  control_service(const char *, const char *);
+void  control_service(const char *, int);
+void  control_service_string(const char *, const char *);
 void  control_service_daemon(const char *, const char *);
 void  setup_dependants();
 void  reset_depend();
