@@ -134,7 +134,7 @@
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: net.c,v 1.71 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: net.c,v 1.72 2006/06/30 16:41:51 martinp Exp $
  *
  *  @file
  */
@@ -646,7 +646,6 @@ double icmp_echo(const char *hostname, int timeout, int count) {
   struct icmp *icmphdrin= NULL;
   struct icmp *icmphdrout[count];
 #endif
-  size_t size;
   fd_set rset;
   int i;
   int s;
@@ -690,13 +689,13 @@ double icmp_echo(const char *hostname, int timeout, int count) {
 #ifdef HAVE_SOL_IP
     icmphdrout[i]->code= 0;
     icmphdrout[i]->type= ICMP_ECHO;
-    icmphdrout[i]->un.echo.id= getpid() + (int)hostname + time(NULL);
+    icmphdrout[i]->un.echo.id= getpid() + (long)hostname + time(NULL);
     icmphdrout[i]->un.echo.sequence= i;
     icmphdrout[i]->checksum= checksum_ip((unsigned char *)icmphdrout[i], ICMP_SIZE);
 #else
     icmphdrout[i]->icmp_code= 0;
     icmphdrout[i]->icmp_type= ICMP_ECHO;
-    icmphdrout[i]->icmp_id= getpid() + (int)hostname + time(NULL);
+    icmphdrout[i]->icmp_id= getpid() + (long)hostname + time(NULL);
     icmphdrout[i]->icmp_seq= i;
     icmphdrout[i]->icmp_cksum= checksum_ip((unsigned char *)icmphdrout[i], ICMP_SIZE);
 #endif
@@ -715,6 +714,8 @@ double icmp_echo(const char *hostname, int timeout, int count) {
   
   do {
 
+    socklen_t size;
+
     FD_ZERO(&rset);
     FD_SET(s, &rset);
 
@@ -728,7 +729,7 @@ double icmp_echo(const char *hostname, int timeout, int count) {
     size= sizeof(struct sockaddr_in);
 
     do {
-      n= recvfrom(s, buf, STRLEN, 0, (struct sockaddr *)&sin, (socklen_t *)&size);
+      n= recvfrom(s, buf, STRLEN, 0, (struct sockaddr *)&sin, &size);
     } while(n == -1 && errno == EINTR);
     
     if(n < 0)
