@@ -44,6 +44,10 @@
 #include <sys/vmmeter.h>
 #endif
 
+#ifdef HAVE_MACH_MACH_H
+#include <mach/mach.h>
+#endif
+
 #ifdef HAVE_MACH_HOST_INFO_H
 #include <mach/host_info.h>
 #endif
@@ -65,7 +69,7 @@
  *  @author Rory Toma <rory@digeo.com>
  *  @author Martin Pala <martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_DARWIN.c,v 1.26 2006/04/27 20:16:03 martinp Exp $
+ *  @version \$Id: sysdep_DARWIN.c,v 1.28 2006/06/21 18:59:54 martinp Exp $
  *
  *  @file
  */
@@ -140,15 +144,16 @@ int initprocesstree_sysdep(ProcessTree_T **reference) {
   int                i;
   int                treesize;
   static kvm_t      *kvm_handle;
-  ProcessTree_T     *pt;
   struct kinfo_proc *pinfo;
+  ProcessTree_T     *pt;
+
 
   if(getuid()!=0) {
     LogError("system statistic error -- permission denied\n");
     return FALSE;
   }
 
-  if(!(kvm_handle = kvm_open(NULL, NULL, NULL, O_RDONLY, NULL)))
+  if(!(kvm_handle = kvm_open(NULL, NULL, NULL, O_RDONLY, "kvm_open: ")))
   {
     LogError("system statistic error -- cannot initialize kvm interface\n");
     return FALSE;
@@ -166,17 +171,27 @@ int initprocesstree_sysdep(ProcessTree_T **reference) {
 
   for(i = 0; i < treesize; i++)
   {
+    mach_port_t task;
+
     pt[i].pid       = pinfo[i].kp_proc.p_pid;
     pt[i].ppid      = pinfo[i].kp_eproc.e_ppid;
     pt[i].cputime   = (long)((pinfo[i].kp_proc.p_rtime.tv_sec * 10) +
                              (pinfo[i].kp_proc.p_rtime.tv_usec / 100000)
                             );
-    pt[i].mem_kbyte = (unsigned long)(pinfo[i].kp_eproc.e_vm.vm_rssize * pagesize_kbyte);
     if(pinfo[i].kp_proc.p_stat == SZOMB)
     {
       pt[i].status_flag |= PROCESS_ZOMBIE;
     }
     pt[i].time = get_float_time();
+
+    if(task_for_pid(mach_task_self(), pt[i].pid, &task) == KERN_SUCCESS) {
+      task_basic_info_data_t info;
+      mach_msg_type_number_t count = TASK_BASIC_INFO_COUNT;
+
+      if(task_info(task, TASK_BASIC_INFO, (task_info_t)&info, &count) == KERN_SUCCESS) {
+        pt[i].mem_kbyte = (unsigned long)(info.resident_size / 1024);
+      }
+    }
   }
 
   *reference = pt;
