@@ -86,7 +86,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Arkadiusz Miskiewicz <arekm@pld-linux.org>
  *
- *  @version \$Id: sysdep_LINUX.c,v 1.32 2006/04/27 20:16:03 martinp Exp $
+ *  @version \$Id: sysdep_LINUX.c,v 1.39 2006/07/04 09:38:21 martinp Exp $
  *
  *  @file
  */
@@ -103,7 +103,7 @@
 static long   old_cpu_user     = 0;
 static long   old_cpu_syst     = 0;
 static long   old_cpu_wait     = 0;
-static double old_time         = 0.0;
+static long   old_cpu_total    = 0;
 static int    page_shift_to_kb = 0;
 
 
@@ -352,11 +352,15 @@ int used_system_memory_sysdep(SystemInfo_T *si) {
  */
 int used_system_cpu_sysdep(SystemInfo_T *si) {
   int    rv;
+  long   cpu_total;
   long   cpu_user;
+  long   cpu_nice;
   long   cpu_syst;
+  long   cpu_idle;
   long   cpu_wait;
+  long   cpu_irq;
+  long   cpu_softirq;
   char   buf[1024];
-  double curr_time = get_float_time();
 
   if(!read_proc_file(buf, 1024, "stat", -1))
   {
@@ -364,20 +368,31 @@ int used_system_cpu_sysdep(SystemInfo_T *si) {
     goto error;
   }
 
-  rv = sscanf(buf, "cpu %ld %*d %ld %*d %ld", &cpu_user, &cpu_syst, &cpu_wait);
-  if(rv < 2 || rv > 3)
+  rv = sscanf(buf, "cpu %ld %ld %ld %ld %ld %ld %ld",
+         &cpu_user,
+         &cpu_nice,
+         &cpu_syst,
+         &cpu_idle,
+         &cpu_wait,
+         &cpu_irq,
+         &cpu_softirq);
+  if(rv < 4)
   {
     LogError("system statistic error -- cannot read cpu usage\n");
     goto error;
   }
-  else
+  else if(rv == 4)
   {
-    cpu_user = (double)cpu_user * 10.0 / HZ / num_cpus;
-    cpu_syst = (double)cpu_syst * 10.0 / HZ / num_cpus;
-    cpu_wait = (rv == 3)?(double)cpu_wait * 10.0 / HZ / num_cpus:0.0;
+    /* linux 2.4.x doesn't support these values */
+    cpu_wait = 0;
+    cpu_irq = 0;
+    cpu_softirq = 0;
   }
-  
-  if(old_time == 0.0)
+
+  cpu_total= cpu_user + cpu_nice + cpu_syst + cpu_idle + cpu_wait + cpu_irq + cpu_softirq;
+  cpu_user = cpu_user + cpu_nice;
+
+  if(old_cpu_total == 0)
   {
     si->total_cpu_user_percent = 0;
     si->total_cpu_syst_percent = 0;
@@ -385,18 +400,20 @@ int used_system_cpu_sysdep(SystemInfo_T *si) {
   }
   else
   {
+    long delta = cpu_total - old_cpu_total;
+  
     si->total_cpu_user_percent =
-      (int)(1000 * (double)(cpu_user - old_cpu_user) / (curr_time - old_time));
+      (int)(1000 * (double)(cpu_user - old_cpu_user) / delta);
     si->total_cpu_syst_percent =
-      (int)(1000 * (double)(cpu_syst - old_cpu_syst) / (curr_time - old_time));
+      (int)(1000 * (double)(cpu_syst - old_cpu_syst) / delta);
     si->total_cpu_wait_percent =
-      (int)(1000 * (double)(cpu_wait - old_cpu_wait) / (curr_time - old_time));
+      (int)(1000 * (double)(cpu_wait - old_cpu_wait) / delta);
   }
-  old_time = curr_time;
 
   old_cpu_user = cpu_user;
   old_cpu_syst = cpu_syst;
   old_cpu_wait = cpu_wait;
+  old_cpu_total= cpu_total;
   return TRUE;
 
   error:
