@@ -37,14 +37,14 @@
  *  Simple MySQL test.
  *
  *  In the case that the anonymous login is possible,
- *  we will perform MySQL ping. If athentication failed
+ *  we will perform MySQL ping. If authentication failed
  *  we suppose the anonymous login is denied and we will
  *  return success, because the server at least performed
  *  authentication => it seems it works.
  *
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: mysql.c,v 1.7 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: mysql.c,v 1.9 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -105,63 +105,60 @@ int check_mysql(Socket_T s) {
   ASSERT(s);
 
   if(!socket_readln(s, (char *)buf, sizeof(buf))) {
-    log("MYSQL: error receiving greeting -- %s\n", STRERROR);
+    LogError("MYSQL: error receiving greeting -- %s\n", STRERROR);
     return FALSE;
   }
 
   if(socket_write(s, requestLogin, sizeof(requestLogin)) < 0) {
-    log("MYSQL: error sending login -- %s\n", STRERROR);
+    LogError("MYSQL: error sending login -- %s\n", STRERROR);
     return FALSE;
   }
 
   /* read just first few bytes  which contains enough information */
   if(socket_read(s, buf, 7) <= 6) {
-    log("MYSQL: error receiving login response -- %s\n", STRERROR);
+    LogError("MYSQL: error receiving login response -- %s\n", STRERROR);
     return FALSE;
   }
 
   /* Compare Packet Number: */
-  if(buf[3] != 0x02)
-  {
-    log("MYSQL: invalid response packet number\n");
+  if(buf[3] != 0x02) {
+    LogError("MYSQL: invalid response packet number\n");
     return FALSE;
   }
 
   /* Compare Response Code: */
 
   /* If OK, we are loged in and will perform MySQL ping */
-  if(buf[4] == 0x00)
-  {
+  if(buf[4] == 0x00) {
     if(socket_write(s, (unsigned char *)requestPing, sizeof(requestPing)) < 0) {
-      log("MYSQL: error sending ping -- %s\n", STRERROR);
+      LogError("MYSQL: error sending ping -- %s\n", STRERROR);
       return FALSE;
     }
 
     if(socket_read(s, buf, sizeof(responsePing)) <= 0) {
-      log("MYSQL: error receiving ping response -- %s\n", STRERROR);
+      LogError("MYSQL: error receiving ping response -- %s\n", STRERROR);
       return FALSE;
     }
 
     if(memcmp((unsigned char *)buf,
   	      (unsigned char *)responsePing, sizeof(responsePing))) {
-      log("MYSQL: ping failed\n");
+      LogError("MYSQL: ping failed\n");
       return FALSE;
     }
 
     if(socket_write(s, (unsigned char *)requestQuit, sizeof(requestQuit)) < 0) {
-      log("MYSQL: error sending quit -- %s\n", STRERROR);
+      LogError("MYSQL: error sending quit -- %s\n", STRERROR);
       return FALSE;
     }
 
     return TRUE;
   }
   /* If Authentication Failed, return success immediately */
-  else if((buf[4] == 0xFF) && (buf[5] == 0x15 && buf[6] == 0x04))
-  {
+  else if((buf[4] == 0xFF) && (buf[5] == 0x15 && buf[6] == 0x04)) {
     return TRUE;
   }
 
-  log("MYSQL: login failed\n");
+  LogError("MYSQL: login failed\n");
 
   return FALSE;
 }
