@@ -42,6 +42,7 @@ static Protocol_T myftp= NULL;
 static Protocol_T mygeneric= NULL;
 static Protocol_T myhttp= NULL;
 static Protocol_T myimap= NULL;
+static Protocol_T myclamav= NULL;
 static Protocol_T myldap2= NULL;
 static Protocol_T myldap3= NULL;
 static Protocol_T mymysql= NULL;
@@ -63,7 +64,7 @@ static Protocol_T mypgsql= NULL;
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: protocol.c,v 1.27 2006/01/22 19:47:36 hauk Exp $
+ *  @version \$Id: protocol.c,v 1.28 2006/08/25 16:28:33 hauk Exp $
  *
  *  @file
  */
@@ -82,6 +83,7 @@ void gc_protocols() {
   FREE(mygeneric);
   FREE(myhttp);
   FREE(myimap);
+  FREE(myclamav);
   FREE(myldap2);
   FREE(myldap3);
   FREE(mymysql);
@@ -178,6 +180,14 @@ void *create_imap() {
   return myimap;
 }
 
+void *create_clamav() {
+  if(myclamav == NULL) {
+    NEW(myclamav);
+    myclamav->name= "CLAMAV";
+    myclamav->check= check_clamav;
+  }
+  return myclamav;
+}
 
 void *create_ldap2() {
   if(myldap2 == NULL) {
