@@ -48,6 +48,7 @@
 #define P_POSTFIXPOLICY  19
 #define P_TNS            20
 #define P_PGSQL          21
+#define P_CLAMAV         22
 
 void  gc_protocols();
 
@@ -60,6 +61,7 @@ void* create_ftp();
 void* create_generic();
 void* create_http();
 void* create_imap();
+void* create_clamav();
 void* create_ldap2();
 void* create_ldap3();
 void* create_mysql();
@@ -83,6 +85,7 @@ int check_ftp(Socket_T);
 int check_generic(Socket_T);
 int check_http(Socket_T);
 int check_imap(Socket_T);
+int check_clamav(Socket_T);
 int check_ldap2(Socket_T);
 int check_ldap3(Socket_T);
 int check_mysql(Socket_T);
