@@ -33,45 +33,66 @@
 
 #include "protocol.h"
 
+
+/* Private prototypes */
+static int send(Socket_T s, char *msg);
+static int expect(Socket_T s, int expect, int log);
+
+
 /**
-*  Check the server for greeting code 220 and then send QUIT and
- *  check for code 221. If alive return TRUE, else, return FALSE.
+ * Check the server for greeting code 220 and send EHLO. If that failed
+ * try HELO and test for return code 250 and finally send QUIT and check
+ * for return code 221. If alive return TRUE else return FALSE.
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Michael Amster, <mamster@webeasy.com>
  *
- *  @version \$Id: smtp.c,v 1.27 2006/04/27 20:16:03 martinp Exp $
+ *  @version \$Id: smtp.c,v 1.31 2006/10/11 12:46:41 martinp Exp $
  *
  *  @file
  */
 int check_smtp(Socket_T s) {
-  
-  int status;
-  char buf[STRLEN];
-  
+    
   ASSERT(s);
   
-  if(!socket_readln(s, buf, sizeof(buf))) {
-    LogError("SMTP: error receiving data -- %s\n", STRERROR);
+  if(!expect(s, 220, TRUE))
     return FALSE;
+  
+  if(!(send(s, "EHLO localhost\r\n") && expect(s, 250, FALSE))) {
+    /* Try HELO also before giving up as of rfc2821 4.1.1.1 */
+    if(!(send(s, "HELO localhost\r\n") && expect(s, 250, TRUE)))
+      return FALSE;
   }
-  
-  Util_chomp(buf);
-  
-  sscanf(buf, "%d%*s", &status);
-  if(status != 220) {
-    LogError("SMTP error: %s\n", buf);
+
+  if(!(send(s, "QUIT\r\n") && expect(s, 221, TRUE)))
     return FALSE;
-  }
+    
+  return TRUE;
   
-  /* Terminate the session */
-  if(socket_print(s, "QUIT\r\n") < 0) {
+}
+
+
+/* --------------------------------------------------------------- Private */
+
+
+static int send(Socket_T s, char *msg) {
+  
+  if(socket_write(s, msg, strlen(msg)) < 0) {
     LogError("SMTP: error sending data -- %s\n", STRERROR);
     return FALSE;
   }
   
-  /* Check the reply */
-  if(!socket_readln(s, buf, sizeof(buf))) {
+  return TRUE;
+  
+}
+
+
+static int expect(Socket_T s, int expect, int log) {
+  
+  int status;
+  char buf[STRLEN];
+
+  if(!socket_readln(s, buf, STRLEN)) {
     LogError("SMTP: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
@@ -79,8 +100,9 @@ int check_smtp(Socket_T s) {
   Util_chomp(buf);
   
   sscanf(buf, "%d%*s", &status);
-  if(status != 221) {
-    LogError("SMTP error: %s\n", buf);
+  if(status != expect) {
+    if(log) 
+      LogError("SMTP error: %s\n", buf);
     return FALSE;
   }
   
