@@ -37,7 +37,7 @@
  * 
  *  @author Igor Homyakov, <homyakov@altlinux.ru>
  *
- *  @version \$Id: ssh.c,v 1.13 2006/04/27 20:16:03 martinp Exp $
+ *  @version \$Id: ssh.c,v 1.14 2006/06/06 11:05:58 martinp Exp $
  *
  *  @file
  */
@@ -62,6 +62,9 @@ int check_ssh(Socket_T s) {
     LogError("SSH: error sending identification string -- %s\n", STRERROR);
     return FALSE;
   }
+
+  /* Read one extra line to prevent the "Read from socket failed" warning */
+  socket_readln(s, buf, sizeof(buf));
    
   return TRUE;
   
