@@ -50,7 +50,7 @@
  * Implementation of the socket interface.
  * 
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
- * @version \$Id: socket.c,v 1.56 2006/01/01 22:44:02 martinp Exp $
+ * @version \$Id: socket.c,v 1.57 2006/06/30 16:41:51 martinp Exp $
  * @file
  */
 
@@ -527,7 +527,7 @@ int socket_read(Socket_T S, void *b, int size) {
     *p++= c;
   }
   
-  return  (int)p - (int)b;
+  return  (long)p - (long)b;
   
 }
 
