@@ -77,7 +77,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Peter Holdaway <pholdaway@technocom-wireless.com>
  *
- *  @version \$Id: spawn.c,v 1.47 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: spawn.c,v 1.48 2006/04/27 20:16:03 martinp Exp $
  *  @file
  */
 
@@ -129,7 +129,7 @@ void spawn(Service_T S, Command_T C, const char *E) {
   ASSERT(C);
 
   if(access(C->arg[0], X_OK) != 0) {
-    log("Error: Could not execute %s\n", C->arg[0]);
+    LogError("Error: Could not execute %s\n", C->arg[0]);
     return;
   }
 
@@ -144,7 +144,7 @@ void spawn(Service_T S, Command_T C, const char *E) {
 
   pid= fork();
   if(pid < 0) {
-    log("Cannot fork a new process\n");  
+    LogError("Cannot fork a new process\n");  
     exit(1); 
   }
 
@@ -211,18 +211,18 @@ void spawn(Service_T S, Command_T C, const char *E) {
 
   /* Wait for first child - aka second parent, to exit */
   if(waitpid(pid, &stat_loc, 0) != pid) {
-      log("Waitpid error\n");
+      LogError("Waitpid error\n");
   }
 
   exit_status= WEXITSTATUS(stat_loc);
   if (exit_status & setgid_ERROR)
-    log("Failed to change gid to '%d' for '%s'\n", C->gid, C->arg[0]);
+    LogError("Failed to change gid to '%d' for '%s'\n", C->gid, C->arg[0]);
   if (exit_status & setuid_ERROR)
-    log("Failed to change uid to '%d' for '%s'\n", C->uid, C->arg[0]);
+    LogError("Failed to change uid to '%d' for '%s'\n", C->uid, C->arg[0]);
   if (exit_status & fork_ERROR)
-    log("Cannot fork a new process for '%s'\n", C->arg[0]);
+    LogError("Cannot fork a new process for '%s'\n", C->arg[0]);
   if (exit_status & redirect_ERROR)
-    log("Cannot redirect IO to /dev/null for '%s'\n", C->arg[0]);
+    LogError("Cannot redirect IO to /dev/null for '%s'\n", C->arg[0]);
 
   free_monit_environment(&environment);
   ASSERT(environment == NULL);
