@@ -119,7 +119,7 @@ static int is_url_unsafe(unsigned char *);
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *  @author Michael Amster, <mamster@webeasy.com> 
  *
- *  @version \$Id: util.c,v 1.184 2006/04/27 20:16:03 martinp Exp $
+ *  @version \$Id: util.c,v 1.186 2006/07/19 17:33:37 martinp Exp $
  *  @file
  */
 
@@ -730,6 +730,13 @@ void Util_printService(Service_T s) {
       actionnames[s->action_PPID->failed->id]);
   }
 
+  if(s->type == TYPE_DEVICE) {
+    printf(" %-20s = if changed %s then %s\n",
+      "Filesystem flags",
+      Util_getEventratio(s->action_FSFLAG->failed, ratio1),
+      actionnames[s->action_FSFLAG->failed->id]);
+  }
+
   if(s->checksum && s->checksum->action) {
     Checksum_T cs= s->checksum;
     EventAction_T a= cs->action;
@@ -862,7 +869,7 @@ void Util_printService(Service_T s) {
         "Size",
         ratio1, actionnames[a->failed->id]);
     else
-      printf(" %-20s = if %s %lu byte(s) %s then %s else if passed %s then %s\n",
+      printf(" %-20s = if %s %llu byte(s) %s then %s else if passed %s then %s\n",
         "Size", operatornames[sl->operator], sl->size,
         ratio1, actionnames[a->failed->id],
         ratio2, actionnames[a->passed->id]);
@@ -1709,8 +1716,10 @@ void Util_resetInfo(Service_T s) {
   memset(s->inf, 0, sizeof *(s->inf));
   s->inf->_pid=        -1;
   s->inf->_ppid=       -1;
+  s->inf->_flags=      -1;
   s->inf->pid=         -1;
   s->inf->ppid=        -1;
+  s->inf->flags=       -1;
   s->inf->st_ino_prev=  0;
   s->inf->readpos=      0;
 }
@@ -1759,7 +1768,7 @@ char *Util_getHTTPHostHeader(Socket_T s, char *hostBuf, int len) {
  * @param rightExpression rval
  * Returns the boolean value of the expression
  */
-int Util_evalQExpression(int operator, int left, int right) {
+int Util_evalQExpression(int operator, long long left, long long right) {
 
   switch(operator) {
   case OPERATOR_GREATER:
