@@ -30,7 +30,7 @@
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *  @author Michael Amster, <mamster@webeasy.com> 
  *
- *  @version \$Id: util.h,v 1.15 2006/04/11 23:23:26 hauk Exp $
+ *  @version \$Id: util.h,v 1.16 2006/07/05 12:47:49 hauk Exp $
  *  @file
  */
 
@@ -371,7 +371,7 @@ char *Util_getHTTPHostHeader(Socket_T s, char *hostBuf, int len);
  * @param rightExpression rval
  * @return the boolean value of the expression
  */
-int Util_evalQExpression(int operator, int left, int right);
+int Util_evalQExpression(int operator, long long left, long long right);
 
 
 /*
