@@ -90,7 +90,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: validate.c,v 1.152 2006/04/27 20:16:03 martinp Exp $
+ *  @version \$Id: validate.c,v 1.157 2006/07/19 17:33:37 martinp Exp $
  *  @file
  */
 
@@ -113,6 +113,7 @@ static void check_process_state(Service_T);
 static void check_process_pid(Service_T);
 static void check_process_ppid(Service_T);
 static void check_connection(Service_T, Port_T);
+static void check_device_flags(Service_T);
 static void check_device_resources(Service_T, Device_T);
 static void check_process_resources(Service_T, Resource_T);
 
@@ -145,10 +146,31 @@ void validate() {
   }
   time(&systeminfo.collected);
 
+  /* In the case that at least one action is pending, perform quick
+   * loop to handle the actions ASAP */
+  if(Run.doaction) {
+    Run.doaction = 0;
+    for(s= servicelist; s; s= s->next) {
+      LOCK(s->mutex)
+        set_signal_block(&ns, &os);
+        if(s->doaction != ACTION_IGNORE) {
+          control_service(s->name, s->doaction);
+          s->doaction = ACTION_IGNORE;
+        }
+        unset_signal_block(&os);
+      END_LOCK;
+    }
+  }
+
+  /* Check the services */
   for(s= servicelist; s; s= s->next) {
     LOCK(s->mutex)
       set_signal_block(&ns, &os);
-      if(s->monitor && !check_skip(s) && !check_timeout(s)) {
+      if(s->doaction != ACTION_IGNORE) {
+        /* Check for pending action which may occured after previous check */
+        control_service(s->name, s->doaction);
+        s->doaction = ACTION_IGNORE;
+      } else if(s->monitor && !check_skip(s) && !check_timeout(s)) {
         s->check(s);
         s->monitor= MONITOR_YES;
       }
@@ -162,6 +184,8 @@ void validate() {
 
   reset_depend();
 
+  handle_collector(NULL);
+
 }
 
 
@@ -264,6 +288,8 @@ int check_device(Service_T s) {
   if(s->gid)
     check_gid(s);
 
+  check_device_flags(s);
+
   if(s->devicelist)
     for(td= s->devicelist; td; td= td->next)
       check_device_resources(s, td);
@@ -1089,7 +1115,7 @@ static void check_size(Service_T s) {
         /* reset expected value for next cycle */
         sl->size= s->inf->st_size;
       } else {
-        DEBUG("'%s' size has not changed [current size=%lu B]\n", s->name,
+        DEBUG("'%s' size has not changed [current size=%llu B]\n", s->name,
               s->inf->st_size);
         Event_post(s, EVENT_CHANGED, STATE_PASSED, sl->action,
           "'%s' size was not changed", s->name, s->path);
@@ -1100,10 +1126,10 @@ static void check_size(Service_T s) {
     /* we are testing constant value for failed or passed state */
     if(Util_evalQExpression(sl->operator, s->inf->st_size, sl->size)) {
       Event_post(s, EVENT_SIZE, STATE_FAILED, sl->action,
-        "'%s' size test failed for %s -- current size is %lu B",
+        "'%s' size test failed for %s -- current size is %llu B",
         s->name, s->path, s->inf->st_size);
     } else {
-      DEBUG("'%s' file size check passed [current size=%lu B]\n", s->name,
+      DEBUG("'%s' file size check passed [current size=%llu B]\n", s->name,
             s->inf->st_size);
       Event_post(s, EVENT_SIZE, STATE_PASSED, sl->action, "'%s' size passed", s->name);
     }
@@ -1318,6 +1344,27 @@ static void check_match_if(Service_T s, char *line) {
   return;
 }
 
+/**
+ * Test filesystem flags for possible change since last cycle
+ */
+static void check_device_flags(Service_T s) {
+
+  ASSERT(s && s->inf);
+
+  /* filesystem flags were not initialized yet */
+  if(s->inf->_flags == -1)
+    return;
+
+  if(s->inf->_flags != s->inf->flags) {
+    Event_post(s, EVENT_CHANGED, STATE_FAILED, s->action_FSFLAG,
+      "'%s' filesytem flags changed to %#lx", s->name, s->inf->flags);
+  } else {
+    DEBUG("'%s' filesystem flags has not changed since last cycle\n", s->name);
+    Event_post(s, EVENT_CHANGED, STATE_PASSED, s->action_FSFLAG,
+      "'%s' filesytem flags has not changed", s->name);
+  }
+}
+
 /**
  * Device test
  */
