@@ -48,7 +48,7 @@
  *  @author Eric S. Raymond <esr@snark.thyrsus.com>
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: xmalloc.c,v 1.13 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: xmalloc.c,v 1.14 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -69,7 +69,7 @@ void *xmalloc(int n) {
 #if ! HAVE_MALLOC
     if ( n == 0) {
 
-      log("%s: passed a broken malloc 0\n", prog);
+      LogError("%s: passed a broken malloc 0\n", prog);
       exit(1);
 
     }
@@ -77,7 +77,7 @@ void *xmalloc(int n) {
 
     if ( p == NULL ) {
       
-      log("%s: malloc failed -- %s\n", prog, STRERROR);
+      LogError("%s: malloc failed -- %s\n", prog, STRERROR);
       exit(1);
       
     }
@@ -93,7 +93,7 @@ void *xcalloc(long count, long nbytes) {
     p= (void *)calloc(count, nbytes);
     if ( p == NULL ) {
       
-      log("%s: malloc failed -- %s\n", prog, STRERROR);
+      LogError("%s: malloc failed -- %s\n", prog, STRERROR);
       exit(1);
       
     }
@@ -143,7 +143,7 @@ void *xresize(void *p, long nbytes) {
   p= realloc(p, nbytes);
   if(p == NULL) {
     
-    log("%s: realloc failed -- %s\n", prog, STRERROR);
+    LogError("%s: realloc failed -- %s\n", prog, STRERROR);
     exit(1);
     
   }
